package com.softslate.commerce.administrator.core;

import java.io.IOException;
import java.util.Properties;

import javax.servlet.ServletException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionServlet;
import org.apache.struts.action.PlugIn;
import org.apache.struts.config.ModuleConfig;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.quartz.impl.StdSchedulerFactory;

import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.daos.core.DAOFactory;

/**
 * 
 * @author Jason McWilliams
 * 
 */
public class QuartzPlugIn implements PlugIn {

	static Log log = LogFactory.getLog(QuartzPlugIn.class);

	private Scheduler quartzScheduler = null;

	public void init(ActionServlet servlet, ModuleConfig moduleConfig) throws ServletException {
		if (log.isInfoEnabled()) {
			log.info("Initializing Quartz.");
		}
		try {
			Properties quartzProperties = null;
			try {
				quartzProperties = loadQuartzProperties(servlet);
			} catch (IOException e) {
				log.info("Exception loading Quartz properties file:", e);
				return;
			}
			if (quartzProperties == null) {
				log.info("Quartz properties files does not exist in this distribution.");
				return;
			}
			try {
				quartzScheduler = new StdSchedulerFactory(quartzProperties).getScheduler();
			} catch (SchedulerException se) {
				if (se.getMessage() != null && se.getMessage().contains("quartz-jobs-custom.xml")) {
					log.warn(se.getMessage()
							+ " If you have upgraded to 3.3.1 or later, add classes/quartz-jobs-custom.xml to avoid this warning.");
					quartzProperties.setProperty("org.quartz.plugin.jobInitializer.fileNames", "quartz-jobs.xml");
					quartzScheduler = new StdSchedulerFactory(quartzProperties).getScheduler();
				} else {
					throw se;
				}
			}
			quartzScheduler.getContext().put("servletContext", servlet.getServletContext());
			int startupDelay = 300;
			if (quartzScheduler.getContext().get("ssStartupDelay") != null) {
				try {
					startupDelay = Integer.parseInt((String) quartzScheduler.getContext().get("ssStartupDelay"));
				} catch (Exception ex) {
					startupDelay = 300;
				}
			}
			quartzScheduler.startDelayed(startupDelay);
			servlet.getServletContext().setAttribute("quartzScheduler", quartzScheduler);
		} catch (SchedulerException e) {
			log.error("Error initializing Quartz: ", e);
		}
		return;
	}

	public void destroy() {
		try {
			// Allow finishing of current jobs if possible
			quartzScheduler.shutdown(true);
		} catch (Exception ex) {
			log.error("Exception stopping the scheduler. ", ex);
		}
	}

	private Properties loadQuartzProperties(ActionServlet servlet) throws IOException {
		DAOFactory daoFactory = (DAOFactory) servlet.getServletContext().getAttribute("daoFactory");
		String quartzPropertiesFile = "quartz.properties";
		if (System.getProperty("quartz.configuration") != null) {
			quartzPropertiesFile = System.getProperty("quartz.configuration");
		}
		Properties quartzProperties = AppUtils.loadProperties(quartzPropertiesFile, servlet.getServletContext());
		if (quartzProperties != null && daoFactory != null && daoFactory.getHibernateSettings() != null) {
			Properties hibernateProperties = daoFactory.getHibernateSettings();
			if (quartzProperties.getProperty("org.quartz.dataSource.myDS.driver") == null) {
				quartzProperties.setProperty("org.quartz.dataSource.myDS.driver",
						hibernateProperties.getProperty("hibernate.connection.driver_class"));
				if (hibernateProperties.getProperty("hibernate.connection.driver_class").contains("postgresql")) {
					quartzProperties.setProperty("org.quartz.jobStore.driverDelegateClass",
							"org.quartz.impl.jdbcjobstore.PostgreSQLDelegate");
				} else if (hibernateProperties.getProperty("hibernate.connection.driver_class").contains("oracle")) {
					quartzProperties.setProperty("org.quartz.jobStore.driverDelegateClass",
							"org.quartz.impl.jdbcjobstore.oracle.OracleDelegate");
				}
			}
			if (quartzProperties.getProperty("org.quartz.dataSource.myDS.URL") == null) {
				quartzProperties.setProperty("org.quartz.dataSource.myDS.URL",
						hibernateProperties.getProperty("hibernate.connection.url"));
			}
			if (quartzProperties.getProperty("org.quartz.dataSource.myDS.user") == null) {
				quartzProperties.setProperty("org.quartz.dataSource.myDS.user",
						hibernateProperties.getProperty("hibernate.connection.username"));
			}
			if (quartzProperties.getProperty("org.quartz.dataSource.myDS.password") == null) {
				quartzProperties.setProperty("org.quartz.dataSource.myDS.password",
						hibernateProperties.getProperty("hibernate.connection.password"));
			}
		}
		return quartzProperties;
	}

}
