package com.softslate.commerce.administrator.email;

import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.customer.Customer;
import com.softslate.commerce.businessobjects.customer.CustomerProcessor;
import com.softslate.commerce.businessobjects.email.Template;
import com.softslate.commerce.businessobjects.email.TemplateProcessor;
import com.softslate.commerce.businessobjects.order.Order;
import com.softslate.commerce.businessobjects.order.OrderProcessor;
import com.softslate.commerce.customer.core.BaseAction;


/**
 * Struts action class corresponding to requests to
 * <code>/administrator/EmailAddForm.do</code>. Creates an empty
 * <code>EmailAddEditForm</code> object.
 * 
 */
public class EmailAddFormAction extends BaseAction {

	static Log log = LogFactory.getLog(EmailAddFormAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) throws Exception {
		if (log.isDebugEnabled()) log.debug("Starting action.");

		EmailAddEditForm baseForm = (EmailAddEditForm) form;

		if (request.getAttribute("reset") != null && request.getAttribute("reset").equals("true")) {
			Class classDefinition = baseForm.getClass();
			baseForm = (EmailAddEditForm) classDefinition.newInstance();
		}

		BusinessObjectFactory bof = (BusinessObjectFactory) request.getAttribute("businessObjectFactory");

		// Load orders for the order drop down.
		OrderProcessor orderProcessor =  bof.createObject(OrderProcessor.class);
		// Collection orders = orderProcessor.loadAllOrders();
		// request.setAttribute("orders", orders);

		// Load customers for the customer drop down.
		CustomerProcessor customerProcessor =  bof.createObject(CustomerProcessor.class);
		// Collection customers = customerProcessor.loadAllCustomers();
		// request.setAttribute("customers", customers);

		// Load customers for the customer drop down.
		TemplateProcessor templateProcessor =  bof.createObject(TemplateProcessor.class);
		// Collection customers = customerProcessor.loadAllCustomers();
		// request.setAttribute("customers", customers);

		Collection bcs = Arrays.asList(new String[] { "Home", "Emails", "Add Email" });

		// Load the parent if an id is present
		Order order = null;
		if (baseForm.getParentOrderID() != null && baseForm.getParentOrderID().length() > 0) {
			Map parameters = new HashMap();
			parameters.put("orderID", baseForm.getParentOrderID());
			order = orderProcessor.loadOrderFromID(parameters);
			request.setAttribute("order", order);
			if (order != null && order.getOrderID() > 0) {
				baseForm.setOrderID(order.getOrderID());
				if (order.getCustomer() != null) {
					baseForm.setCustomerID(order.getCustomer().getCustomerID());
				}
			}
			// Create breadcrumbing collection
			bcs = Arrays.asList(new String[] { "Home", "Orders", "Order Details", "Emails", "Add Email" });
			request.setAttribute("breadcrumbs", bcs);
		}

		// Load the parent if an id is present
		Customer customer = null;
		if (baseForm.getParentCustomerID() != null && baseForm.getParentCustomerID().length() > 0) {
			Map parameters = new HashMap();
			parameters.put("customerID", baseForm.getParentCustomerID());
			customer = customerProcessor.loadCustomerFromID(parameters);
			request.setAttribute("customer", customer);
			if (customer != null && customer.getCustomerID() > 0) {
				baseForm.setCustomerID(customer.getCustomerID());
			}
			// Create breadcrumbing collection
			bcs = Arrays.asList(new String[] { "Home", "Customers", "Customer Details", "Emails", "Add Email" });
			request.setAttribute("breadcrumbs", bcs);
		}

		// Load the parent if an id is present
		Template template = null;
		if (baseForm.getParentTemplateID() != null && baseForm.getParentTemplateID().length() > 0) {
			Map parameters = new HashMap();
			parameters.put("templateID", baseForm.getParentTemplateID());
			template = templateProcessor.loadTemplateFromID(parameters);
			request.setAttribute("template", template);
			if (template != null && template.getTemplateID() > 0) {
				baseForm.setTemplateID(template.getTemplateID());
			}
			// Create breadcrumbing collection
			bcs = Arrays.asList(new String[] { "Home", "Templates", "Template Details", "Emails", "Add Email" });
			request.setAttribute("breadcrumbs", bcs);
		}

		baseForm.initializeProperties(mapping, request);
		request.setAttribute("emailAddEditForm", baseForm);
		request.setAttribute("breadcrumbs", bcs);

		return mapping.findForward("success");
	}
}
