package com.softslate.commerce.administrator.email;

import java.util.Arrays;
import java.util.Collection;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.softslate.commerce.businessobjects.email.EmailOptOut;
import com.softslate.commerce.businessobjects.email.EmailOptOutProcessor;
import com.softslate.commerce.businessobjects.email.Template;
import com.softslate.commerce.businessobjects.email.TemplateProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class corresponding to requests to
 * "/administrator/EmailOptOutEditForm.do". Loads in the current values of the
 * record being edited and populates a <code>EmailOptOutAddEditForm</code>
 * object.
 */
public class EmailOptOutEditFormAction extends BaseAction {

	static Log log = LogFactory.getLog(EmailOptOutAddFormAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) throws Exception {
		if (log.isDebugEnabled()) log.debug("Starting action.");
		EmailOptOutAddEditForm baseForm = (EmailOptOutAddEditForm) form;
		baseForm.initializeProperties(mapping, request);

		// Get the record to edit
		EmailOptOutProcessor processor =  baseForm.getBusinessObjectFactory().createObject(EmailOptOutProcessor.class);
		EmailOptOut emailOptOut = processor.loadEmailOptOutFromID(PropertyUtils.describe(form));
		BeanUtils.copyProperties(baseForm, emailOptOut);
		
		TemplateProcessor tProcessor = (TemplateProcessor) baseForm.getBusinessObjectFactory().createObject(
				"templateProcessorImplementer");
		Collection<Template> templates = tProcessor.loadAllTemplates();
		request.setAttribute("templates", templates);
		
		// Enforce role permissions
		if (!request.isUserInRole("superuser") && !request.isUserInRole("administrator") && !request.isUserInRole("emailOptOutEdit")) {
			request.setAttribute("editPermission", "false");
		} else {
			request.setAttribute("editPermission", "true");
		}

		// Create breadcrumbing collection
		Collection bcs = Arrays.asList(new String[] { "Home", "Email Opt Outs", "Email Opt Out Details" });
		request.setAttribute("breadcrumbs", bcs);

		request.setAttribute("emailOptOut", emailOptOut);
		request.setAttribute("emailOptOutAddEditForm", baseForm);
		return mapping.findForward("success");
	}
}
