package com.softslate.commerce.administrator.extender;

import java.io.File;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Properties;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.LogFactory;

public class Extension {

	static org.apache.commons.logging.Log log = LogFactory.getLog(Extension.class);

	protected Extension() {
	}

	public Extension(Properties extenderProperties, Properties appComponents, File webinfDirectory) throws Exception {
		setAppComponents(appComponents);
		setEntityName(extenderProperties.getProperty("entity"));
		setForeignKeyNames(extenderProperties.getProperty("foreignKeys").split(","));
		setFieldNamesAndTypes(extenderProperties.getProperty("fields").split(","));
		setCreateAdminInterface(extenderProperties.getProperty("createAdminInterface") != null
				&& extenderProperties.getProperty("createAdminInterface").equals("true"));
		setUpdateExistingEntity(extenderProperties.getProperty("updateExistingEntity") != null
				&& extenderProperties.getProperty("updateExistingEntity").equals("true"));
		setOverwriteExistingFiles(extenderProperties.getProperty("overwriteExistingFiles") != null
				&& extenderProperties.getProperty("overwriteExistingFiles").equals("true"));
		if (!getOverwriteExistingFiles()) {
			File output = new File(webinfDirectory, "extenderOutput");
			output.mkdir();
			setOutputDirectory(output);
			log.info("Overwrite flag not set, will attempt to write files to: " + output.getAbsolutePath());
		} else {
			log.info("Overwrite flag IS set, will attempt to write files to: " + webinfDirectory.getAbsolutePath());
			setOutputDirectory(webinfDirectory);
		}
		setSourceDirectory(new File(webinfDirectory, "src"));
		validateEntityName();
		setEntity(new Entity(getEntityName(), getAppComponents()));
		setFields(initializeFields(getFieldNamesAndTypes(), getAppComponents()));
		setForeignKeys(initializeForeignKeys(getForeignKeyNames(), getAppComponents()));
		setMergeTokenHtmlXmlStart("<!-- " + getEntity().getCappedName()
				+ " entity auto-generated by SoftSlate Extender - Start -->");
		setMergeTokenHtmlXmlEnd("<!-- " + getEntity().getCappedName()
				+ " entity auto-generated by SoftSlate Extender - End -->");
		setMergeTokenJSPStart("<%-- " + getEntity().getCappedName()
				+ " entity auto-generated by SoftSlate Extender - Start --%>");
		setMergeTokenJSPEnd("<%-- " + getEntity().getCappedName()
				+ " entity auto-generated by SoftSlate Extender - End --%>");
		setMergeTokenPropertiesStart("# " + getEntity().getCappedName()
				+ " entity auto-generated by SoftSlate Extender - Start");
		setMergeTokenPropertiesEnd("# " + getEntity().getCappedName()
				+ " entity auto-generated by SoftSlate Extender - End");
		setMergeTokenJavaStart("/\\* " + getEntity().getCappedName()
				+ " fields auto-generated by SoftSlate Extender - Start \\*/");
		setMergeTokenJavaEnd("/\\* " + getEntity().getCappedName()
				+ " fields auto-generated by SoftSlate Extender - End \\*/");
	}

	private Entity entity = null;
	private Collection<ForeignKey> foreignKeys = null;
	private Collection<Field> fields = null;
	private String entityName = null;
	private String[] foreignKeyNames = null;
	private String[] fieldNamesAndTypes = null;
	private boolean createAdminInterface = false;
	private boolean updateExistingEntity = false;
	private boolean overwriteExistingFiles = false;
	private File outputDirectory = null;
	private File velocityTemplateDirectory = null;
	private File sourceDirectory = null;
	private Properties appComponents = null;
	private String javadocAuthor = "Auto-Generated by SoftSlate Extender";
	private String mergeTokenHtmlXmlStart = null;
	private String mergeTokenHtmlXmlEnd = null;
	private String mergeTokenJSPStart = null;
	private String mergeTokenJSPEnd = null;
	private String mergeTokenPropertiesStart = null;
	private String mergeTokenPropertiesEnd = null;
	private String mergeTokenJavaStart = null;
	private String mergeTokenJavaEnd = null;
	protected String entityContents = null;
	protected String entityBeanContents = null;
	protected String entityBeanHBMXMLContents = null;
	protected String entityAlterSQLContents = null;
	protected String entityCreateSQLContents = null;
	protected String entityProcessorContents = null;
	protected String entityBasicProcessorContents = null;
	protected String entityDAOContents = null;
	protected String entityDAOHibernateContents = null;
	protected String entityGatewayDAOContents = null;
	protected String entityGatewayDAOHibernateContents = null;
	protected String entityAppComponentContents = null;
	protected String entityQueriesContents = null;
	protected String entityActionContents = null;
	protected String entityAddActionContents = null;
	protected String entityAddEditFormContents = null;
	protected String entityAddFormActionContents = null;
	protected String entityDeleteActionContents = null;
	protected String entityEditActionContents = null;
	protected String entityEditDeleteActionContents = null;
	protected String entityEditFormActionContents = null;
	protected String entityFormContents = null;
	protected String entityAddFormContents = null;
	protected String entityEditFormContents = null;
	protected String entityFormGutsContents = null;
	protected String entityFieldColumnsContents = null;
	protected String entityHeadingContents = null;
	protected String entityExtraContents = null;
	protected String entityStrutsContents = null;
	protected String entityTilesContents = null;
	protected String entityNavigationLookupContents = null;
	protected String entitySideContents = null;
	protected String entityChangingEventContents = null;
	protected String entityChangingEventImplContents = null;
	protected String entityCRUDAPIContents = null;

	public Entity getEntity() {
		return entity;
	}

	public void setEntity(Entity entity) {
		this.entity = entity;
	}

	public boolean isCreateAdminInterface() {
		return createAdminInterface;
	}

	public boolean getUpdateExistingEntity() {
		return updateExistingEntity;
	}

	public void setUpdateExistingEntity(boolean updateExistingEntity) {
		this.updateExistingEntity = updateExistingEntity;
	}

	public boolean getOverwriteExistingFiles() {
		return overwriteExistingFiles;
	}

	public void setOverwriteExistingFiles(boolean overwriteExistingFiles) {
		this.overwriteExistingFiles = overwriteExistingFiles;
	}

	public String getEntityName() {
		return entityName;
	}

	public void setEntityName(String entityName) {
		this.entityName = entityName;
	}

	public String getJavadocAuthor() {
		return javadocAuthor;
	}

	public String[] getForeignKeyNames() {
		return foreignKeyNames;
	}

	public void setForeignKeyNames(String[] foreignKeyNames) {
		this.foreignKeyNames = foreignKeyNames;
	}

	public String[] getFieldNamesAndTypes() {
		return fieldNamesAndTypes;
	}

	public void setFieldNamesAndTypes(String[] fieldNamesAndTypes) {
		this.fieldNamesAndTypes = fieldNamesAndTypes;
	}

	public Collection getForeignKeys() {
		return foreignKeys;
	}

	public void setForeignKeys(Collection foreignKeys) {
		this.foreignKeys = foreignKeys;
	}

	public Collection getFields() {
		return fields;
	}

	public void setFields(Collection fields) {
		this.fields = fields;
	}

	public Properties getAppComponents() {
		return appComponents;
	}

	public void setAppComponents(Properties appComponents) {
		this.appComponents = appComponents;
	}

	public void setCreateAdminInterface(boolean createAdminInterface) {
		this.createAdminInterface = createAdminInterface;
	}

	public File getOutputDirectory() {
		return outputDirectory;
	}

	public void setOutputDirectory(File outputDirectory) {
		this.outputDirectory = outputDirectory;
	}

	public File getVelocityTemplateDirectory() {
		if (velocityTemplateDirectory == null) {
			File com = new File(getSourceDirectory(), "com");
			File softslate = new File(com, "softslate");
			File commerce = new File(softslate, "commerce");
			File administrator = new File(commerce, "administrator");
			velocityTemplateDirectory = new File(administrator, "extender");
		}
		return velocityTemplateDirectory;
	}

	public void setVelocityTemplateDirectory(File velocityTemplateDirectory) {
		this.velocityTemplateDirectory = velocityTemplateDirectory;
	}

	public File getSourceDirectory() {
		if (sourceDirectory == null) {
			sourceDirectory = new File(getOutputDirectory(), "src");
		}
		return sourceDirectory;
	}

	public void setSourceDirectory(File sourceDirectory) {
		this.sourceDirectory = sourceDirectory;
	}

	public void validateEntityName() throws Exception {
		if (StringUtils.isBlank(getEntityName())) {
			throw new Exception("Entity name not defined.");
		}
		return;
	}

	public Collection<Field> initializeFields(String[] fieldsAndTypes, Properties appComponents) {
		Collection<Field> fieldObjects = new ArrayList();
		for (int i = 0; i < fieldsAndTypes.length; i++) {
			String fieldNameAndType = fieldsAndTypes[i].trim();
			if (fieldNameAndType.length() > 0) {
				String fieldName = fieldNameAndType.split("\\|")[0].trim();
				String fieldType = fieldNameAndType.split("\\|")[1].trim();
				Field field = new Field(fieldName, fieldType, appComponents);
				fieldObjects.add(field);
			}
		}
		return fieldObjects;
	}

	public Collection<ForeignKey> initializeForeignKeys(String[] foreignKeys, Properties appComponents) {
		Collection<ForeignKey> foreignKeyObjects = new ArrayList();
		for (int i = 0; i < foreignKeys.length; i++) {
			if (foreignKeys[i].trim().length() > 0) {
				ForeignKey foreignKey = new ForeignKey(foreignKeys[i].trim(), appComponents);
				foreignKeyObjects.add(foreignKey);
			}
		}
		return foreignKeyObjects;
	}

	public String getMergeTokenHtmlXmlStart() {
		return mergeTokenHtmlXmlStart;
	}

	public void setMergeTokenHtmlXmlStart(String mergeTokenHtmlXmlStart) {
		this.mergeTokenHtmlXmlStart = mergeTokenHtmlXmlStart;
	}

	public String getMergeTokenPropertiesStart() {
		return mergeTokenPropertiesStart;
	}

	public void setMergeTokenPropertiesStart(String mergeTokenPropertiesStart) {
		this.mergeTokenPropertiesStart = mergeTokenPropertiesStart;
	}

	public String getMergeTokenHtmlXmlEnd() {
		return mergeTokenHtmlXmlEnd;
	}

	public void setMergeTokenHtmlXmlEnd(String mergeTokenHtmlXmlEnd) {
		this.mergeTokenHtmlXmlEnd = mergeTokenHtmlXmlEnd;
	}

	public String getMergeTokenPropertiesEnd() {
		return mergeTokenPropertiesEnd;
	}

	public void setMergeTokenPropertiesEnd(String mergeTokenPropertiesEnd) {
		this.mergeTokenPropertiesEnd = mergeTokenPropertiesEnd;
	}

	public String getMergeTokenJSPStart() {
		return mergeTokenJSPStart;
	}

	public void setMergeTokenJSPStart(String mergeTokenJSPStart) {
		this.mergeTokenJSPStart = mergeTokenJSPStart;
	}

	public String getMergeTokenJSPEnd() {
		return mergeTokenJSPEnd;
	}

	public void setMergeTokenJSPEnd(String mergeTokenJSPEnd) {
		this.mergeTokenJSPEnd = mergeTokenJSPEnd;
	}

	public String getMergeTokenJavaStart() {
		return mergeTokenJavaStart;
	}

	public void setMergeTokenJavaStart(String mergeTokenJavaStart) {
		this.mergeTokenJavaStart = mergeTokenJavaStart;
	}

	public String getMergeTokenJavaEnd() {
		return mergeTokenJavaEnd;
	}

	public void setMergeTokenJavaEnd(String mergeTokenJavaEnd) {
		this.mergeTokenJavaEnd = mergeTokenJavaEnd;
	}

}
