package com.softslate.commerce.administrator.importexport;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.importexport.BasicImportExportProcessor;
import com.softslate.commerce.businessobjects.importexport.ImportProcessor;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Action class corresponding to /ImportProcess.do, which processes a text file
 * import.
 * 
 * @author David Tobey, Ashish Jain
 * 
 */
public class ImportProcessAction extends BaseAction {

	static Log log = LogFactory.getLog(ImportProcessAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request,
			HttpServletResponse response) throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		ImportForm baseForm = (ImportForm) form;
		Collection records = (Collection) request.getSession().getAttribute("importedRecords");
		baseForm.setRecords(records);
		String tableName = baseForm.getTable();
		String[] headerRow = baseForm.getFields();

		ActionErrors errors = new ActionErrors();
		ActionMessages messages = new ActionMessages();

		synchronized (AppUtils.getSessionLock(request.getSession())) {
			try {

				validateSelectedHeaderForCode(headerRow, tableName);

				BusinessObjectFactory bof = (BusinessObjectFactory) request.getAttribute("businessObjectFactory");

				Map parameters = PropertyUtils.describe(baseForm);

				Collection businessMaps = this.transformToMaps(headerRow, records);

				ImportProcessor importProcessor =  bof.createObject(ImportProcessor.class);

				Map results = importProcessor.processImport(tableName, businessMaps, parameters);

				Exception exception = (Exception) results.get("exception");
				String exceptionKey = (String) results.get("exceptionKey");
				String exceptionValue = (String) results.get("exceptionValue");
				if (exception != null) {
					String message = exceptionKey + " = " + exceptionValue + ": " + exception.toString();
					errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("errors.import", message));
					saveErrors(request, (ActionMessages) errors);
					return mapping.findForward("failure");

				}

				Integer insertsCount = ((Integer) results.get("insertRecordsCount"));
				Integer updatesCount = ((Integer) results.get("updateRecordsCount"));
				Integer skippedCount = ((Integer) results.get("skippedRecordsCount"));
				Integer failedCount = ((Integer) results.get("failRecordsCount"));
				Collection importMessages = (Collection) results.get("resultMessages");

				request.setAttribute("insertCount", insertsCount);
				request.setAttribute("updateCount", updatesCount);
				request.setAttribute("skippedCount", skippedCount);
				request.setAttribute("failCount", failedCount);
				request.setAttribute("importMessages", importMessages);

				// Set the success message
				messages.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("messages.importSuccessful"));
				saveMessages(request, messages);

				// Define the breadcrumbing
				Collection bcs = Arrays.asList(new String[] { "Home", "Import Form " + baseForm.getTable(),
						"Import - Preview and Identify Fields", "Import Results" });
				request.setAttribute("breadcrumbs", bcs);

				return mapping.findForward("success");
			} catch (Exception ex) {
				log.error(ex);

				errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("errors.detail", ex.getMessage()));
				saveErrors(request, (ActionMessages) errors);
				return mapping.findForward("failure");
			} finally {
				request.getSession().removeAttribute("importedRecords");
			}
		}
	}

	private Collection transformToMaps(String[] headerRow, Collection records) throws Exception {
		ArrayList bObjects = null;
		if (null != records) {
			Iterator iterator = records.iterator();
			bObjects = new ArrayList();
			while (iterator.hasNext()) {
				String[] record = (String[]) iterator.next();
				Map map = this.transformToMap(headerRow, record);
				bObjects.add(map);
			}
		}
		return bObjects;
	}

	private Map transformToMap(String[] fields, String[] record) throws Exception {
		Map beanMap = new HashMap();
		for (int j = 0; j < fields.length; j++)
			if (!fields[j].equalsIgnoreCase("") && record.length > j)
				beanMap.put(fields[j], record[j]);

		return beanMap;
	}

	private boolean validateSelectedHeaderForCode(String[] headerRow, String tableName) throws Exception {
		boolean result = false;
		if (tableName.equals(BasicImportExportProcessor.PRODUCT_TABLE))
			result = checkForHeaderForCode2(headerRow, "code");
		else if (tableName.equals(BasicImportExportProcessor.CATEGORY_TABLE))
			result = checkForHeaderForCode2(headerRow, "code");
		else if (tableName.equals(BasicImportExportProcessor.ATTRIBUTE_TABLE))
			result = checkForHeaderForCode2(headerRow, "attributeCode");
		else if (tableName.equals(BasicImportExportProcessor.OPTION_TABLE)) {
			result = checkForHeaderForCode2(headerRow, "attributeCode");
			if (result)
				result = checkForHeaderForCode2(headerRow, "optionCode");
		} else if (tableName.equals(BasicImportExportProcessor.PRODUCT_SETTING_TABLE)) {
			result = checkForHeaderForCode2(headerRow, "productCode");
			if (result)
				result = checkForHeaderForCode2(headerRow, "code");
		}
		return result;
	}

	private boolean checkForHeaderForCode2(String[] headerRow, String fieldName) throws Exception {
		if (null != headerRow)
			for (int i = 0; i < headerRow.length; i++)
				if (headerRow[i].equalsIgnoreCase(fieldName))
					return true;

		throw new Exception("Required Field is not present, FieldName = " + fieldName);
	}

}
