package com.softslate.commerce.administrator.importexport;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.importexport.ImportProcessor;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseAction;

import au.com.bytecode.opencsv.CSVReader;

/**
 * Action class corresponding to /ImportPreviewProcess.do, which handles the
 * uploading of an import file, and displaying the import preview.
 * 
 * @author David Tobey, Ashish Jain
 * 
 */
public class ImportUploadAction extends BaseAction {

	static Log log = LogFactory.getLog(ImportUploadAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");

		ImportForm baseForm = (ImportForm) form;
		ActionErrors errors = new ActionErrors();

		synchronized (AppUtils.getSessionLock(request.getSession())) {
			// Determine the path to the file to import
			String fileToImportPath = getFile(baseForm);
			String selectedTableName = baseForm.getTable();

			if (fileToImportPath.equals("Same file exists")) {
				errors
						.add(
								ActionMessages.GLOBAL_MESSAGE,
								new ActionMessage(
										"errors.detail",
										"The selected file aleady exists on server. Either overwrite or choose different file name."));
				saveErrors(request, (ActionMessages) errors);
				return mapping.findForward("failure");
			}

			// Check that the file exists
			File fileToImport = new File(fileToImportPath);
			if (!fileToImport.exists()) {
				errors.add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage(
						"errors.detail",
						"The selected file was not found on the server."));
				saveErrors(request, (ActionMessages) errors);
				return mapping.findForward("failure");
			}

			// Determine the delimiter - comma by default
			char delimiter = ',';
			if (baseForm.getDelimiter().equals("tab")) {
				delimiter = (char) 9;
			} else if (baseForm.getDelimiter().equals("pipe")) {
				delimiter = '|';
			}

			boolean headerPresent = false;
			if (baseForm.getHeaderRow().equalsIgnoreCase("true"))
				headerPresent = true;

			// Parse!
			FileReader fileReader = new FileReader(fileToImport);
			CSVReader parser = new CSVReader(fileReader, delimiter);
			List records = parser.readAll();

			Collection dataRecords = null;

			if (null != records && headerPresent) {
				String[] parsedHeaderFields = (String[]) records.get(0);
				baseForm.setParsedHeaderFields(parsedHeaderFields);
				dataRecords = records.subList(1, records.size());
			} else {
				dataRecords = records;
				baseForm.setParsedHeaderFields(new String[] {});
			}

			baseForm.setRecords(dataRecords);
			request.getSession().setAttribute("importedRecords", dataRecords);

			// Set the field options based on the table
			if (baseForm.getFieldOptions() == null) {
				BusinessObjectFactory bof = (BusinessObjectFactory) request
						.getAttribute("businessObjectFactory");
				ImportProcessor importProcessor =  bof
						.createObject(ImportProcessor.class);

				Collection columns = importProcessor.loadColumnNames(
						selectedTableName, true);

				baseForm.setFieldOptions(columns);
			}

			// Enforce role permissions
			if (!request.isUserInRole("superuser")
					&& !request.isUserInRole("administrator")
					&& !request.isUserInRole("importexportEdit")) {
				request.setAttribute("editPermission", "false");
			} else {
				request.setAttribute("editPermission", "true");
			}


			// Create breadcrumbing collection
			Collection bcs = Arrays.asList(new String[] { "Home",
					"Import Form " + baseForm.getTable(),
					"Import - Preview and Identify Fields" });
			request.setAttribute("breadcrumbs", bcs);

			return mapping.findForward("success");
		}
	}

	private String getFile(ImportForm baseForm) throws FileNotFoundException,
			IOException {
		String fileToImportPath;
		File tempdir = (File) getServlet().getServletContext().getAttribute(
				"javax.servlet.context.tempdir");
		// Handle the uploaded file, if any
		if (baseForm.getUseFileOnServer().equals("false")
				&& baseForm.getFile() != null
				&& baseForm.getFile().getFileSize() > 0) {
			// Build path for the file on the server
			if (baseForm.getOverwrite().equalsIgnoreCase("false")) {
				String[] files = tempdir.list();
				if (null != files && files.length > 0)
					for (int i = 0; i < files.length; i++)
						if (baseForm.getFile().getFileName().equalsIgnoreCase(
								files[i])) {
							return "Same file exists";
						}
			}

			File file = new File(tempdir, baseForm.getFile().getFileName());
			// Write the file to the temp directory
			InputStream stream = baseForm.getFile().getInputStream();
			OutputStream bos = new FileOutputStream(file);
			int bytesRead = 0;
			byte[] buffer = new byte[8192];
			while ((bytesRead = stream.read(buffer, 0, 8192)) != -1) {
				bos.write(buffer, 0, bytesRead);
			}
			bos.close();
			stream.close();
			fileToImportPath = file.getPath();
			baseForm.setPathOnServer(fileToImportPath);
		} else {

			fileToImportPath = baseForm.getPathOnServer();
		}
		return fileToImportPath;
	}
}
