package com.softslate.commerce.administrator.order;

import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.softslate.commerce.businessobjects.order.Order;
import com.softslate.commerce.businessobjects.order.OrderDelivery;
import com.softslate.commerce.businessobjects.order.OrderDeliveryProcessor;
import com.softslate.commerce.businessobjects.order.OrderProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class corresponding to requests to
 * <code>/administrator/OrderAddForm.do</code>. Creates a new, empty order.
 * 
 * @author David Tobey
 * 
 */
public class OrderAddFormAction extends BaseAction {

	static Log log = LogFactory.getLog(OrderAddFormAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");

		OrderAddEditForm baseForm = (OrderAddEditForm) form;
		baseForm.initializeProperties(mapping, request);
		Map parameters = new HashMap();

		// Create a new, empty order
		OrderProcessor processor = (OrderProcessor) baseForm
				.getBusinessObjectFactory().createObject(
						"orderProcessorImplementer");
		Map results = processor.addOrder(parameters);
		Order order = (Order) results.get("newRecord");

		// Add an OrderDelivery object, too
		OrderDeliveryProcessor odProcessor = (OrderDeliveryProcessor) baseForm
				.getBusinessObjectFactory().createObject(
						"orderDeliveryProcessorImplementer");
		parameters.put("order", order);
		results = odProcessor.addOrderDelivery(parameters);
		OrderDelivery orderDelivery = (OrderDelivery) results.get("newRecord");
		order.setOrderDeliveryCollection(new LinkedHashSet());
		order.getOrderDeliveryCollection().add(orderDelivery);

		// Enforce role permissions
		if (!request.isUserInRole("superuser")
				&& !request.isUserInRole("administrator")
				&& !request.isUserInRole("orderEdit")) {
			request.setAttribute("editPermission", "false");
		} else {
			request.setAttribute("editPermission", "true");
		}

		// Create breadcrumbing collection
		Collection bcs = Arrays.asList(new String[] { "Home", "Orders",
				"Order Details" });
		request.setAttribute("breadcrumbs", bcs);

		request.setAttribute("order", order);
		BeanUtils.copyProperties(baseForm, order);
		request.setAttribute("orderAddEditForm", baseForm);

		return mapping.findForward("success");
	}
}
