package com.softslate.commerce.administrator.order;

import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.order.Order;
import com.softslate.commerce.businessobjects.order.OrderItem;
import com.softslate.commerce.businessobjects.order.OrderItemProcessor;
import com.softslate.commerce.businessobjects.order.OrderProcessor;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * Struts action class corresponding to requests to
 * <code>/administrator/OrderItemAttributeAddForm.do</code>. Creates an empty
 * <code>OrderItemAttributeAddEditForm</code> object.
 * 
 * @author David Tobey
 * 
 */
public class OrderItemAttributeAddFormAction extends BaseAction {

	static Log log = LogFactory.getLog(OrderItemAttributeAddFormAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");

		OrderItemAttributeAddEditForm baseForm = (OrderItemAttributeAddEditForm) form;

		if (request.getAttribute("reset") != null
				&& request.getAttribute("reset").equals("true")) {
			Class classDefinition = baseForm.getClass();
			baseForm = (OrderItemAttributeAddEditForm) classDefinition
					.newInstance();
		}

		baseForm.initializeProperties(mapping, request);
		request.setAttribute("orderItemAttributeAddEditForm", baseForm);
		baseForm.setOrderItemID(request.getParameter("orderItemID"));

		// Load the parent
		BusinessObjectFactory bof = (BusinessObjectFactory) request
				.getAttribute("businessObjectFactory");
		OrderItem orderItem = null;
		if (baseForm.getOrderItemID() != null
				&& baseForm.getOrderItemID().length() > 0) {
			OrderItemProcessor processor =  bof
					.createObject(OrderItemProcessor.class);
			orderItem = processor.loadOrderItemFromID(PropertyUtils
					.describe(baseForm));
			request.setAttribute("orderItem", orderItem);
		}

		// Load the parent order if an id is present
		Order order = null;
		if (orderItem != null && orderItem.getOrderID() > 0) {
			Map parameters = new HashMap();
			parameters.put("orderID", Integer.toString(orderItem.getOrderID()));
			OrderProcessor parentProcessor =  bof
					.createObject(OrderProcessor.class);
			order = parentProcessor.loadOrderFromID(parameters);
			request.setAttribute("order", order);
		}

		request.setAttribute("orderItemAttributeAddEditForm", baseForm);

		// Create breadcrumbing collection
		Collection bcs = Arrays.asList(new String[] { "Home", "Orders",
				"Order Details", "Order Items", "Order Item Details",
				"Order Item Attributes", "Add Order Item Attribute" });
		request.setAttribute("breadcrumbs", bcs);

		// Create childSubNavigation collection
		Collection childsn = Arrays.asList(new String[] { "Order Item Details",
				"Order Item Attributes", "Add Order Item Attribute" });
		request.setAttribute("childSubNavigation", childsn);

		return mapping.findForward("success");
	}
}
