package com.softslate.commerce.administrator.product;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringEscapeUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.product.Discount;
import com.softslate.commerce.businessobjects.product.DiscountProcessor;
import com.softslate.commerce.customer.core.ActionUtils;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.product.ProductInitializer;

/**
 * Struts action class that corresponds to requests to
 * "/administrator/DiscountEdit.do". Processes a request to edit a record within
 * the system.
 * 
 * @author David Tobey
 */
public class DiscountEditAction extends BaseAction {

	static Log log = LogFactory.getLog(DiscountEditAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		
		DiscountAddEditForm baseForm = (DiscountAddEditForm) form;

		// Handle generating the code from the name if it is empty
		ActionUtils actionUtils = (ActionUtils) baseForm
				.getBusinessObjectFactory().createUtilsObject(
						"actionUtilsImplementer");
		if ((baseForm.getCode() == null || baseForm.getCode().equals(""))
				&& (baseForm.getName() != null && !baseForm.getName()
						.equals(""))) {
			baseForm.setCode(actionUtils.generateCodeFromName(baseForm
					.getName()));
		}

		// Edit the record
		DiscountProcessor processor = (DiscountProcessor) baseForm
				.getBusinessObjectFactory().createObject(
						"discountProcessorImplementer");

		// Preserve parameters that were set during baseForm.validate.
		Map parameters = baseForm.mapOfIncomingParams();
		if (baseForm.getStartDate() != null) {
			parameters.put("startDate", baseForm.getStartDate());
		}
		if (baseForm.getExpirationDate() != null) {
			parameters.put("expirationDate", baseForm.getExpirationDate());
		}
		if (baseForm.getUsersAppliesValue() != null) {
			parameters.put("usersAppliesValue", baseForm.getUsersAppliesValue());
		}
		if (baseForm.getCartItemsValue() != null) {
			parameters.put("cartItemsValue", baseForm.getCartItemsValue());
		}
		if (baseForm.getCartItemsValue() != null) {
			parameters.put("cartItemsValue", baseForm.getCartItemsValue());
		}
		if (baseForm.getReward() != null) {
			parameters.put("reward", baseForm.getReward());
		}
		Map results = processor.editDiscount(parameters);

		// Successful edit
		if (results == null || results.get("resultCode") == null
				|| results.get("resultCode").equals("0")) {

			// Reload the store discounts in the application scope
			ProductInitializer pi = new ProductInitializer();
			pi.setServlet(servlet);
			pi.initializeStoreDiscounts(baseForm.getBusinessObjectFactory());

			// entity.jsp wants the updated record in the request scope
			request.setAttribute("discount", results.get("updatedRecord"));

			// Set the success messages
			baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("messages.recordSaved"));
			saveMessages(baseForm.getRequest(), baseForm.getMessages());

			return mapping.findForward("success");
		}

		// Set the error messages
		if (results != null && results.get("existingRecord") != null) {
			Discount existingRecord = (Discount) results.get("existingRecord");
			String existingCode = StringEscapeUtils.escapeXml11(existingRecord.getCode());
			request.setAttribute("okNotToEscapeMessages", Boolean.TRUE);
			baseForm.getErrors().add(
					ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.resultCode"
							+ results.get("resultCode"), results
							.get("duplicateField"), existingCode));
			baseForm.getErrors().add(
					ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.editExistingRecord",
							"DiscountEditForm.do?discountID="
									+ existingRecord.getDiscountID(), results
									.get("duplicateField"), existingCode));
			saveErrors(baseForm.getRequest(), (ActionMessages) baseForm
					.getErrors());
		}

		return mapping.findForward("success");
	}
}
