package com.softslate.commerce.administrator.product;

import java.util.Arrays;
import java.util.Collection;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.product.Product;
import com.softslate.commerce.businessobjects.product.ProductProcessor;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.core.BaseForm;

/**
 * @author David Tobey
 * 
 */
public class ProductSettingsFormAction extends BaseAction {

	static Log log = LogFactory.getLog(ProductSettingsFormAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isDebugEnabled())
			log.debug("Starting action.");
		BaseForm baseForm = (BaseForm) form;
		baseForm.initializeProperties(mapping, request);
		Map properties = PropertyUtils.describe(form);

		// Load settings
		ProductProcessor productProcessor = (ProductProcessor) baseForm
				.getBusinessObjectFactory().createObject(
						"productProcessorImplementer");
		try {
			request.setAttribute("productSettings",
					productProcessor.loadSettings(properties));
		} catch (Exception e) {
			log.error(e.toString(), e);
			baseForm.getErrors()
					.add(ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.settingsLoadError", e
									.toString()));
			saveErrors(request, (ActionMessages) baseForm.getErrors());
			return mapping.findForward("error");
		}

		// Load parent product
		Product product = productProcessor.loadProductFromID(PropertyUtils
				.describe(form));
		request.setAttribute("product", product);

		if (request.getAttribute("productSettingAddEditForm") == null) {
			ProductSettingAddEditForm productSettingAddEditForm = new ProductSettingAddEditForm();
			productSettingAddEditForm.initializeProperties(mapping, request);
			productSettingAddEditForm.setProductID(request
					.getParameter("productID"));
			productSettingAddEditForm.setParentName(request
					.getParameter("parentName"));
			request.setAttribute("productSettingAddEditForm",
					productSettingAddEditForm);
		}

		// Enforce role permissions
		if (!request.isUserInRole("superuser")
				&& !request.isUserInRole("administrator")
				&& !request.isUserInRole("productEdit")) {
			request.setAttribute("editPermission", "false");
		} else {
			request.setAttribute("editPermission", "true");
		}

		// Create breadcrumbing collection
		Collection bcs = Arrays.asList(new String[] { "Home", "Products",
				"Product Details", "Product Settings" });
		request.setAttribute("breadcrumbs", bcs);

		// Create more subnavigation collection
		Collection moresn = Arrays.asList(new String[] { "Product Other Settings", "Product Custom Settings",
				"Additional Images", "IFrames/Videos", "Product File Downloads", "Product File Attachments",
				"Clone Product", "Product Inventory Settings", "Product Facets" });
		request.setAttribute("moreSubNavigation", moresn);

		if (log.isDebugEnabled())
			log.debug("Finished with Action.");
		return mapping.findForward("success");
	}
}
