package com.softslate.commerce.businessobjects.core;

/**
 * Interface representing a single application request log entry stored in the
 * <code>sscRequestLog</code> database table.
 * <p>
 * When the application needs to create an instance that implements
 * <code>RequestLog</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "requestLogImplementer" setting in the <code>appComponents.properties</code>
 * file.
 * <p>
 * The default "requestLogImplementer" is
 * {@link com.softslate.commerce.businessobjects.core.RequestLogBean}.
 * 
 * @author David Tobey
 */
public interface RequestLog extends BusinessObject {

	public abstract int getRequestLogID();

	public abstract void setRequestLogID(int requestLogID);

	public abstract Integer getOrderID();

	public abstract void setOrderID(Integer orderID);

	public abstract Integer getOrderNumber();

	public abstract void setOrderNumber(Integer orderNumber);

	public abstract Integer getCustomerID();

	public abstract void setCustomerID(Integer customerID);

	public abstract String getCustomerUserName();

	public abstract void setCustomerUserName(String customerUserName);

	public abstract Integer getAdministratorID();

	public abstract void setAdministratorID(Integer administratorID);

	public abstract String getAdministratorUserName();

	public abstract void setAdministratorUserName(String administratorUserName);

	public abstract String getSessionID();

	public abstract void setSessionID(String sessionID);

	public abstract String getIpAddress();

	public abstract void setIpAddress(String ipAddress);

	public abstract String getReferrer();

	public abstract void setReferrer(String referrer);

	public abstract String getUserAgent();

	public abstract void setUserAgent(String userAgent);

	public abstract String getServletPath();

	public abstract void setServletPath(String servletPath);

	public abstract String getRequestURL();

	public abstract void setRequestURL(String requestURL);

	public abstract String getRequestParameters();

	public abstract void setRequestParameters(String requestParameters);

	public String getSearchString();

	public void setSearchString(String searchString);

	public abstract boolean getIsAdminRequest();

	public abstract void setIsAdminRequest(boolean isAdminRequest);

	public abstract String getCreated();

	public abstract void setCreated(String created);

}