package com.softslate.commerce.businessobjects.order;

import java.util.HashMap;
import java.util.Map;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.softslate.commerce.businessobjects.core.BaseBusinessProcessor;
import com.softslate.commerce.daos.order.CountryDAO;
import com.softslate.commerce.daos.order.CountryGatewayDAO;

/**
 * Processes business logic having to do with countries. Created in the Struts
 * layer in response to requests for viewing, editing, adding, and deleting
 * countries.
 * <p>
 * <code>BasicCountryProcessor</code> is the default implementation of the
 * <code>CountryProcessor</code> interface for the application.
 * 
 * @author David Tobey
 * 
 */
public class BasicCountryProcessor extends BaseBusinessProcessor implements
        CountryProcessor {

    static Log log = LogFactory.getLog(BasicCountryProcessor.class);

    public Map loadCountriesAndCount(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName()
                    + ": Loading countries and count");
        CountryGatewayDAO gatewayDAO =  getDaoFactory()
                .createDAO(CountryGatewayDAO.class);
        return gatewayDAO.loadCountriesAndCount(parameters);
    }

    public Map addCountry(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null) {
            String code = (String) parameters.get("code");
            log.info(getUser().getAdministrator().getUserName()
                    + ": Adding country: " + code);
        }
		Map results = new HashMap();
        Country country = (Country) getBusinessObjectFactory().createObject(
                "countryImplementer");
        BeanUtils.copyProperties(country, parameters);
        CountryDAO dao = (CountryDAO) getDaoFactory().createDAO(
                "countryDAOImplementer");
        dao.setCountry(country);
        dao.insertCountry(true);
		results.put("newRecord", dao.getCountry());
		return results;
    }

    public Country loadCountryFromID(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null)
            log.info(getUser().getAdministrator().getUserName()
                    + ": Loading country from id");
        Country country = (Country) getBusinessObjectFactory().createObject(
                "countryImplementer");
        CountryDAO dao = (CountryDAO) getDaoFactory().createDAO(
                "countryDAOImplementer");
        BeanUtils.copyProperties(country, parameters);
        dao.setCountry(country);
        dao.loadCountryFromID();
		return dao.getCountry();
    }

    public Map editCountry(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null) {
            String code = (String) parameters.get("code");
            log.info(getUser().getAdministrator().getUserName()
                    + ": Editing country: " + code);
        }
		Map results = new HashMap();
		Country country = loadCountryFromID(parameters);
        BeanUtils.copyProperties(country, parameters);
        CountryDAO dao = (CountryDAO) getDaoFactory().createDAO(
                "countryDAOImplementer");
        dao.setCountry(country);
        dao.updateCountry(true);
		results.put("updatedRecord", dao.getCountry());
		return results;
    }

	public Map editDeleteCountries(Map parameters) throws Exception {
		if (log.isInfoEnabled() && getUser().getAdministrator() != null)
			log.info(getUser().getAdministrator().getUserName() + ": Editing/deleting multiple countries");
		CountryGatewayDAO dao =  getDaoFactory().createDAO(CountryGatewayDAO.class);
		Map results = dao.editDeleteCountries(parameters, getBusinessObjectFactory());
		return results;
	}

    public void deleteCountry(Map parameters) throws Exception {
        if (log.isInfoEnabled() && getUser().getAdministrator() != null) {
            String code = (String) parameters.get("code");
            log.info(getUser().getAdministrator().getUserName()
                    + ": Deleting country: " + code);
        }
        Country country = (Country) getBusinessObjectFactory().createObject(
                "countryImplementer");
        BeanUtils.copyProperties(country, parameters);
        CountryDAO dao = (CountryDAO) getDaoFactory().createDAO(
                "countryDAOImplementer");
        dao.setCountry(country);
        dao.deleteCountry(true);
        return;
    }
}
