package com.softslate.commerce.businessobjects.order;

import java.io.Serializable;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BaseBusinessObject;
import com.softslate.commerce.businessobjects.product.Discount;

/**
 * Object representing a order discount within the system.
 * <code>OrderDiscountBean</code> is the default implementation of the
 * <code>OrderDiscount</code> interface for the application.
 * <p>
 * The database stores order discounts in the <code>sscOrderDiscount</code>
 * table, and this interface can be used to represent a single row of that
 * table. The Hibernate configuration file <code>OrderDiscount.hbm.xml</code>
 * maps that table's columns to the properties in this object.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudOrderDiscount")
public class OrderDiscountBean extends BaseBusinessObject implements
		OrderDiscount, Serializable {

	private static final long serialVersionUID = 8339854230196161551L;

	private int orderDiscountID = 0;

	private int orderID = 0;

	private Integer orderItemID = null;

	private Double total = null;

	private Integer discountID = null;

	private String code = null;

	private String name = null;

	private String usersAppliesType = null;

	private String usersAppliesValue = null;

	private String itemsAppliesType = null;

	private String itemsAppliesValue = null;

	private String cartItemsType = null;

	private String cartItemsValue = null;

	private String rewardType = null;

	private Double reward = null;

	private String couponCode = null;

	private Double floor = null;

	private Double ceiling = null;

	private String extra1 = null;

	private String extra2 = null;

	private String extra3 = null;

	private int discountOrder = 0;

	private Order order = null;

	private OrderItem orderItem = null;

	private Discount discount = null;

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getDiscount()
	 */
	public Discount getDiscount() {
		return discount;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setDiscount(com.softslate.commerce.businessobjects.product.Discount)
	 */
	public void setDiscount(Discount discount) {
		this.discount = discount;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getOrder()
	 */
	public Order getOrder() {
		return order;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setOrder(com.softslate.commerce.businessobjects.order.Order)
	 */
	public void setOrder(Order order) {
		this.order = order;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getOrderItem()
	 */
	public OrderItem getOrderItem() {
		return orderItem;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setOrderItem(com.softslate.commerce.businessobjects.order.OrderItem)
	 */
	public void setOrderItem(OrderItem orderItem) {
		this.orderItem = orderItem;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getCode()
	 */
	public String getCode() {
		return code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setCode(java.lang.String)
	 */
	public void setCode(String code) {
		this.code = code;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getCouponCode()
	 */
	public String getCouponCode() {
		return couponCode;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setCouponCode(java.lang.String)
	 */
	public void setCouponCode(String couponCode) {
		this.couponCode = couponCode;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getExtra1()
	 */
	public String getExtra1() {
		return extra1;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setExtra1(java.lang.String)
	 */
	public void setExtra1(String extra1) {
		this.extra1 = extra1;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getExtra2()
	 */
	public String getExtra2() {
		return extra2;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setExtra2(java.lang.String)
	 */
	public void setExtra2(String extra2) {
		this.extra2 = extra2;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getExtra3()
	 */
	public String getExtra3() {
		return extra3;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setExtra3(java.lang.String)
	 */
	public void setExtra3(String extra3) {
		this.extra3 = extra3;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getName()
	 */
	public String getName() {
		return name;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setName(java.lang.String)
	 */
	public void setName(String name) {
		this.name = name;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getItemsAppliesType()
	 */
	public String getItemsAppliesType() {
		return itemsAppliesType;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setItemsAppliesType(java.lang.String)
	 */
	public void setItemsAppliesType(String itemsAppliesType) {
		this.itemsAppliesType = itemsAppliesType;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getItemsAppliesValue()
	 */
	public String getItemsAppliesValue() {
		return itemsAppliesValue;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setItemsAppliesValue(java.lang.String)
	 */
	public void setItemsAppliesValue(String itemsAppliesValue) {
		this.itemsAppliesValue = itemsAppliesValue;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getUsersAppliesType()
	 */
	public String getUsersAppliesType() {
		return usersAppliesType;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setUsersAppliesType(java.lang.String)
	 */
	public void setUsersAppliesType(String usersAppliesType) {
		this.usersAppliesType = usersAppliesType;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getUsersAppliesValue()
	 */
	public String getUsersAppliesValue() {
		return usersAppliesValue;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setUsersAppliesValue(java.lang.String)
	 */
	public void setUsersAppliesValue(String usersAppliesValue) {
		this.usersAppliesValue = usersAppliesValue;
	}

	public String getCartItemsType() {
		return cartItemsType;
	}

	public void setCartItemsType(String cartItemsType) {
		this.cartItemsType = cartItemsType;
	}

	public String getCartItemsValue() {
		return cartItemsValue;
	}

	public void setCartItemsValue(String cartItemsValue) {
		this.cartItemsValue = cartItemsValue;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getReward()
	 */
	public Double getReward() {
		return reward;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setReward(java.lang.Double)
	 */
	public void setReward(Double reward) {
		this.reward = reward;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getRewardType()
	 */
	public String getRewardType() {
		return rewardType;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setRewardType(java.lang.String)
	 */
	public void setRewardType(String rewardType) {
		this.rewardType = rewardType;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getCeiling()
	 */
	public Double getCeiling() {
		return ceiling;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setCeiling(java.lang.Double)
	 */
	public void setCeiling(Double ceiling) {
		this.ceiling = ceiling;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getDiscountID()
	 */
	public Integer getDiscountID() {
		return discountID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setDiscountID(java.lang.Integer)
	 */
	public void setDiscountID(Integer discountID) {
		this.discountID = discountID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getFloor()
	 */
	public Double getFloor() {
		return floor;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setFloor(java.lang.Double)
	 */
	public void setFloor(Double floor) {
		this.floor = floor;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getOrderDiscountID()
	 */
	public int getOrderDiscountID() {
		return orderDiscountID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setOrderDiscountID(int)
	 */
	public void setOrderDiscountID(int orderDiscountID) {
		this.orderDiscountID = orderDiscountID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getOrderID()
	 */
	public int getOrderID() {
		return orderID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setOrderID(int)
	 */
	public void setOrderID(int orderID) {
		this.orderID = orderID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getOrderItemID()
	 */
	public Integer getOrderItemID() {
		return orderItemID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setOrderItemID(java.lang.Integer)
	 */
	public void setOrderItemID(Integer orderItemID) {
		this.orderItemID = orderItemID;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getTotal()
	 */
	public Double getTotal() {
		return total;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setTotal(java.lang.Double)
	 */
	public void setTotal(Double total) {
		this.total = total;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#getDiscountOrder()
	 */
	public int getDiscountOrder() {
		return discountOrder;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.softslate.commerce.businessobjects.order.fawe#setDiscountOrder(int)
	 */
	public void setDiscountOrder(int discountOrder) {
		this.discountOrder = discountOrder;
	}

}
