package com.softslate.commerce.businessobjects.product;

import java.io.Serializable;
import java.text.NumberFormat;
import java.util.Collection;
import java.util.Currency;
import java.util.Iterator;
import java.util.Locale;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.softslate.commerce.businessobjects.core.BaseBusinessObject;

/**
 * Object representing a list of products in the system.
 * <p>
 * <code>ProductListBean</code> is the default implementation of the
 * <code>ProductList</code> interface for the application.
 * 
 * @author David Tobey
 * 
 * @see com.softslate.commerce.businessobjects.product.ProductList
 */
public class ProductListBean extends BaseBusinessObject implements ProductList,
        Serializable {

	private static final long serialVersionUID = 5681906350066635658L;

	public static final int ALL_ACTIVE = 1;

    public static final int CATEGORY = 2;

    public static final int SEARCH = 3;

    public static final int MANUFACTURER = 4;
    
    public static final int WISH_LIST = 5;

    static Log log = LogFactory.getLog(ProductListBean.class);

    private int productListType = ALL_ACTIVE;

    public int getProductListType() {
        return (this.productListType);
    }

    public void setProductListType(int productListType) {
        this.productListType = productListType;
    }

    private int categoryID = 0;

    public int getCategoryID() {
        return (this.categoryID);
    }

    public void setCategoryID(int categoryID) {
        this.categoryID = categoryID;
    }

    private int manufacturerID = 0;

	public int getManufacturerID() {
		return manufacturerID;
	}

	public void setManufacturerID(int manufacturerID) {
		this.manufacturerID = manufacturerID;
	}
	
	private int customerWishListID = 0;

	public int getCustomerWishListID() {
		return customerWishListID;
	}

	public void setCustomerWishListID(int customerWishListID) {
		this.customerWishListID = customerWishListID;
	}

    private int itemsPerPage = 20;

    public int getItemsPerPage() {
        return (this.itemsPerPage);
    }

    public void setItemsPerPage(int itemsPerPage) {
        this.itemsPerPage = itemsPerPage;
    }

    private int firstRow = 1;

    public int getFirstRow() {
        return (this.firstRow);
    }

    public void setFirstRow(int firstRow) {
        this.firstRow = firstRow;
    }

    private int itemCount = 0;

    public int getItemCount() {
        return (this.itemCount);
    }

    public void setItemCount(int itemCount) {
        this.itemCount = itemCount;
    }

    private String searchString = null;

    public String getSearchString() {
        return (this.searchString);
    }

    public void setSearchString(String searchString) {
        this.searchString = searchString;
    }

    private Collection productListCollection = null;

    public Collection getProductListCollection() {
        return (this.productListCollection);
    }

    public void setProductListCollection(Collection productListCollection) {
        this.productListCollection = productListCollection;
    }

    public void addFormatting(Locale locale, String currencyCode) {
        if (currencyCode == null) {
            currencyCode = "USD";
        }
        NumberFormat nf = NumberFormat.getCurrencyInstance(locale);
        Currency currency = Currency.getInstance(currencyCode);
        nf.setCurrency(currency);
        Iterator rows = getProductListCollection().iterator();
        while (rows.hasNext()) {
            Product product = (Product) rows.next();
            product.addFormatting(locale, currencyCode);
        }
    }

}
