package com.softslate.commerce.businessobjects.product;

import java.util.Map;

import com.softslate.commerce.businessobjects.core.BusinessProcessor;

/**
 * Interface for business logic methods having to do with product settings.
 * Created in the Struts layer in response to requests for viewing, editing,
 * adding, and deleting product settings.
 * <p>
 * When the application needs to create an instance that implements
 * <code>ProductSettingProcessor</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "productSettingProcessorImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "productSettingProcessorImplementer" is
 * {@link com.softslate.commerce.businessobjects.product.ProductSettingProcessor}.
 * 
 * @author David Tobey
 */
public interface ProductSettingProcessor extends BusinessProcessor {

	abstract Map addProductSetting(Map parameters) throws Exception;

	abstract ProductSetting loadProductSettingFromID(Map parameters)
			throws Exception;

	abstract ProductSetting loadProductSettingFromCode(Map parameters) throws Exception;

	abstract Map editProductSetting(Map parameters) throws Exception;

	abstract void deleteProductSetting(Map parameters) throws Exception;

	abstract int loadMaxProductSettingID() throws Exception;

	abstract Map loadProductSettingsAndCount(Map<String, Object> describe) throws Exception;
	
}
