package com.softslate.commerce.businessobjects.product;

import java.io.Serializable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BaseBusinessObject;

/**
 * Object representing a sku discount in the system.
 * <code>SKUDiscountBean</code> is the default implementation of the
 * <code>SKUDiscount</code> interface for the application.
 * <p>
 * The database stores sku discounts in the <code>sscSKUDiscount</code> table,
 * and this interface can be used to represent a single row of that table. The
 * Hibernate configuration file <code>SKUDiscountBean.hbm.xml</code> maps that
 * table's columns to the properties in this object.
 * 
 * @author David Tobey
 */
@Audited
@AuditTable("AudSKUDiscount")
public class SKUDiscountBean extends BaseBusinessObject implements SKUDiscount,
		Serializable {

	private static final long serialVersionUID = 7937778358470474464L;

	static Log log = LogFactory.getLog(SKUDiscountBean.class);

	private int skuDiscountID = 0;

	public int getSkuDiscountID() {
		return (this.skuDiscountID);
	}

	public void setSkuDiscountID(int skuDiscountID) {
		this.skuDiscountID = skuDiscountID;
	}

	private int discountID = 0;

	public int getDiscountID() {
		return (this.discountID);
	}

	public void setDiscountID(int discountID) {
		this.discountID = discountID;
	}

	private int skuID = 0;

	public int getSkuID() {
		return (this.skuID);
	}

	public void setSkuID(int skuID) {
		this.skuID = skuID;
	}

	private Discount discount;

	public Discount getDiscount() {
		return discount;
	}

	public void setDiscount(Discount discount) {
		this.discount = discount;
	}

	private SKU sku;

	public SKU getSku() {
		return sku;
	}

	public void setSku(SKU sku) {
		this.sku = sku;
	}
}
