package com.softslate.commerce.businessobjects.tax;

import org.hibernate.envers.AuditTable;
import org.hibernate.envers.Audited;

import com.softslate.commerce.businessobjects.core.BusinessObject;
import com.softslate.commerce.businessobjects.order.Country;
import com.softslate.commerce.businessobjects.order.State;

/**
 * Interface representing a basic tax rate within the system. A basic tax rate
 * is the percentage tax that should be applied for a given country, and
 * optionally a given state, city, and postal code.
 * <p>
 * When the application needs to create an instance that implements
 * <code>sscBasicTaxRate</code>,
 * {@link com.softslate.commerce.businessobjects.core.BusinessObjectFactory}
 * finds the name of the Java class to instantiate from the
 * "basicTaxRateImplementer" setting in the
 * <code>appComponents.properties</code> file.
 * <p>
 * The default "basicTaxRateImplementer" is
 * {@link com.softslate.commerce.businessobjects.tax.BasicTaxRateBean}.
 * 
 * @author David Tobey
 * 
 */
@Audited
@AuditTable("AudBasicTaxRate")
public interface BasicTaxRate extends BusinessObject {
	abstract int getBasicTaxRateID();

	abstract void setBasicTaxRateID(int basicTaxRateID);

	abstract String getCity();

	abstract void setCity(String city);

	abstract Integer getCountryID();

	abstract void setCountryID(Integer countryID);

	abstract boolean getIsActive();

	abstract void setIsActive(boolean isActive);

	abstract String getPostalCode();

	abstract void setPostalCode(String postalCode);

	abstract Double getRate();

	abstract void setRate(Double rate);

	abstract Integer getStateID();

	abstract void setStateID(Integer stateID);

	abstract Country getCountry();

	abstract void setCountry(Country country);

	abstract State getState();

	abstract void setState(State state);
}
