package com.softslate.commerce.customer.core;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.softslate.commerce.businessobjects.core.Settings;

/**
 * 
 * @author David Tobey
 * 
 */
public class SecurityHeadersFilter extends BaseFilter implements Filter {
	static Log log = LogFactory.getLog(SecurityHeadersFilter.class);
	private FilterConfig filterConfig = null;

	public void init(FilterConfig filterConfig) throws ServletException {
		this.filterConfig = filterConfig;
	}

	public void destroy() {
	}

	public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
			throws IOException, ServletException {

		// Must cast the request and response to HttpServletRequest and HttpServletResponse
		HttpServletRequest req = (HttpServletRequest) request;
		HttpServletResponse res = (HttpServletResponse) response;

		try {
			doXFrameOptionsHeader(req, res);
			doContentPolicyHeader(req, res);
		} catch (Exception e) {
			log.error("Exception setting security headers (swallowing): " + e);
		}

		// Pass the request along
		chain.doFilter(request, response);
		return;
	}

	private void doXFrameOptionsHeader(HttpServletRequest req, HttpServletResponse res) {

		// The value of the X-Frame-Options response header - we will set default to allow iframes to be included only
		// by pages that live in the same domain.
		String xFrameOptionsValue = "sameorigin";

		// Override the default with the value of the xFrameOptionsHeader.
		Settings settings = (Settings) filterConfig.getServletContext().getAttribute("settings");
		if (settings != null) {
			xFrameOptionsValue = settings.getValue("xFrameOptionsHeader");

			// Exception for requests to the 'IFrameCommunicator' html page. This is an empty .html page that
			// Authorize.net includes from within *its* iframe, in order to communicate back to SoftSlate after the
			// payment info is submitted on their side. It's the only known time a SoftSlate page needs to be included
			// as an iframe on another site.
			String iFrameCommunicatorUrl = settings.getValue("authorizeNetHostedIFrameCommunicatorUrl");
			String servletPath = req.getServletPath();
			if (StringUtils.isNotBlank(iFrameCommunicatorUrl) && servletPath.contains(iFrameCommunicatorUrl)) {

				// Note: FF does not seem to support having the x-frame-options header allow both 'sameorigin' and a
				// specific external site, so for this one URI we will not return the header at all. This seems safe
				// because the 'IFrameCommunicator' page doesn't display anything meaningful. We need to allow
				// 'sameorigin' because the authorize.net page itself is included in a parent SoftSlate page (the
				// checkout payment page). IE, there are three levels.
				xFrameOptionsValue = "";
			}
		}

		// Set the header
		if (StringUtils.isNotBlank(xFrameOptionsValue)) {
			res.setHeader("X-Frame-Options", xFrameOptionsValue);
		}
	}

	private void doContentPolicyHeader(HttpServletRequest req, HttpServletResponse res) {
		Settings settings = (Settings) filterConfig.getServletContext().getAttribute("settings");
		if (settings != null) {
			String contentPolicyResponseHeader = settings.getValue("contentPolicyResponseHeader");
			if (StringUtils.isNotBlank(contentPolicyResponseHeader)) {
				res.setHeader("Content-Security-Policy", contentPolicyResponseHeader);
			}
		}

	}
}
