package com.softslate.commerce.customer.customer;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.BeanUtils;
import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.customer.CustomerAddressProcessor;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseAction;
import com.softslate.commerce.customer.order.AddressesForm;

/**
 * Struts action class used for requests to view the account addresses form.
 * Used for requests to "/AccountAddresses.do".
 * <p>
 * The <code>execute</code> method of this class prepares an instance of
 * {@link com.softslate.commerce.customer.order.AddressesForm}. If the current
 * user is a logged in customer, it populates the form's properties with
 * information from the customer's account.
 * 
 * @author David Tobey
 */
public class AccountAddressesAction extends BaseAction {
	static Log log = LogFactory.getLog(AccountAddressesAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isInfoEnabled())
			log.info("Starting action.");
		AddressesForm baseForm = (AddressesForm) form;
		baseForm.setServlet(getServlet());
		baseForm.initializeProperties(mapping, request);
		synchronized (AppUtils.getSessionLock(baseForm.getRequest().getSession())) {

			// Preserve the original request so the customer is redirected
			// back here after logging in
			request
					.setAttribute("originalRequest", request
							.getRequestURI());
			
			// If the user is not logged in, it's an error.
			if (baseForm.getUser().getCustomer() == null) {
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.userNotLoggedIn"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm
						.getErrors());
				if (log.isInfoEnabled() && !baseForm.getErrors().isEmpty())
					log.info("Validation error(s): "
							+ baseForm.getErrors().toString());
				return mapping.findForward("notLoggedIn");
			}
			String allowAddressBook = (String) baseForm.getSettings().getValue(
					"allowAddressBook");
			if ("1".equals(allowAddressBook)) {
				prepareAddressBookForm(baseForm);
			} else {
				prepareAddressesForm(baseForm);
			}

			return mapping.findForward("success");
		}
	}

	public void prepareAddressBookForm(AddressesForm baseForm) throws Exception {
		if (log.isDebugEnabled())
			log.debug("Preparing the account address book form.");
		// Address book now is for both billing and shipping
		// BeanUtils.copyProperties(baseForm, baseForm.getUser().getCustomer());
		// baseForm.prepareStateAndOtherFields(baseForm.getUser().getCustomer());
		// baseForm.getRequest().setAttribute("addressForm", baseForm);
		return;
	}

	public void prepareAddressesForm(AddressesForm baseForm) throws Exception {
		if (log.isDebugEnabled())
			log.debug("Preparing the account addresses form.");

		// Copy in values from the customer object
		if (baseForm.getUser() != null
				&& baseForm.getUser().getCustomer() != null) {
			BeanUtils
					.copyProperties(baseForm, baseForm.getUser().getCustomer());
			if (baseForm.getUser().getCustomer().getFirstAddress() != null) {
				CustomerAddressProcessor cap = baseForm.getBusinessObjectFactory().createObject(
						CustomerAddressProcessor.class);
				BeanUtils.copyProperties(baseForm, cap.describeDeliveryOrBillingForAddressBook(
						PropertyUtils.describe(baseForm.getUser().getCustomer().getFirstAddress()), "delivery", false));
			}
		}

		// Copy in values submitted from the request, overriding those of the
		// customer object.
		if (baseForm.getRequest().getParameterMap() != null) {
			BeanUtils.populate(baseForm, baseForm.getRequest()
					.getParameterMap());
		}
		baseForm.prepareStateAndOtherFields(baseForm.getUser().getCustomer());
		baseForm.getRequest().setAttribute("addressForm", baseForm);
		return;
	}
}
