package com.softslate.commerce.customer.order;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.customer.core.ActionUtils;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseForm;

/**
 * Struts action class for submissions of payment information during checkout.
 * Used for requests to "/CheckoutPayment.do".
 * <p>
 * The <code>execute</code> method of this class runs
 * {@link com.softslate.commerce.customer.core.ActionUtils#findCheckoutScreen(BaseForm)}
 * to verifiy that the user has made it this far in the checkout process. It
 * then invokes
 * {@link com.softslate.commerce.customer.order.CheckoutAction#processCheckoutPayment(BaseForm)}
 * to process the request.
 * 
 * @author David Tobey
 */
public class CheckoutPaymentAction extends CheckoutPaymentFormAction {
	static Log log = LogFactory.getLog(CheckoutPaymentAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
			throws Exception {
		if (log.isInfoEnabled())
			log.info("Starting action.");

		// Create a BaseForm
		BaseForm baseForm = new BaseForm();
		baseForm.setServlet(getServlet());
		baseForm.initializeProperties(mapping, request);

		synchronized (AppUtils.getSessionLock(baseForm.getRequest().getSession())) {
			// If user is resubmitting, clear the session of previous payment
			// info.
			baseForm.getRequest().getSession().setAttribute(
					"validatedPaymentForm", null);
			baseForm.getRequest().getSession().setAttribute("paymentProcessor",
					null);
			// Make sure the user is allowed to have this action performed.
			ActionUtils actionUtils = (ActionUtils) baseForm
					.getBusinessObjectFactory().createUtilsObject(
							"actionUtilsImplementer");
			String checkoutScreen = actionUtils.findCheckoutScreen(baseForm);
			if (!(checkoutScreen.equals("checkoutPayment") || checkoutScreen.equals("checkoutAjaxOnePagePayment"))) {
				if (request.getAttribute("isApiRequest") != null && (Boolean) request.getAttribute("isApiRequest")) {
					baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
							new ActionMessage("errors.checkoutPaymentWrongStep"));
					saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				}
				return baseForm.getMapping().findForward(checkoutScreen);
			}

			// Process the form.
			return processCheckoutPayment(baseForm);
		}
	}

}
