package com.softslate.commerce.customer.payment;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.businessobjects.customer.Customer;
import com.softslate.commerce.businessobjects.payment.AuthorizeNetAPIProcessor;
import com.softslate.commerce.customer.core.AppUtils;
import com.softslate.commerce.customer.core.BaseAction;

/**
 * 
 * @author Jason McWilliams
 * 
 */
public class AuthorizeNetAddProfileAction extends BaseAction {
	static Log log = LogFactory.getLog(AuthorizeNetAddProfileAction.class);

	public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request,
			HttpServletResponse response) throws Exception {

		if (log.isInfoEnabled())
			log.info("Starting action.");
		AuthorizeNetBillingAddressForm baseForm = (AuthorizeNetBillingAddressForm) form;
		synchronized (AppUtils.getSessionLock(request.getSession())) {

			// Check the Authorize.net settings to make sure the action is allowed.
			String authorizeNetAllowManageProfiles = baseForm.getSettings().getValue("authorizeNetAllowManageProfiles");
			if (request.getAttribute("authorizeNetProfilesOnAndEnabled") == null
					|| !(Boolean) request.getAttribute("authorizeNetProfilesOnAndEnabled")
					|| authorizeNetAllowManageProfiles == null || !authorizeNetAllowManageProfiles.equals("1")) {
				log.info("CIM is not an active payment processor.");
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.cimManageProfilesNotAllowed"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				return mapping.findForward("failure");
			}

			// If the user is not logged in, it's an error.
			if (baseForm.getUser().getCustomer() == null) {
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("errors.userNotLoggedIn"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				log.info("Validation error(s): " + baseForm.getErrors().toString());
				return mapping.findForward("notLoggedIn");
			}

			// Check Settings
			String authorizeNetIntegrationMethod = (String) baseForm.getSettings()
					.getValue("authorizeNetIntegrationMethod");
			if ("AcceptHostedIframe".equals(authorizeNetIntegrationMethod)) {
				log.info("authorizeNetIntegrationMethod can't be 'AcceptHostedIframe'");
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.cimManageProfilesNotAllowedAPI"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				return mapping.findForward("failure");
			}

			// We could try to add a cim profile here if we can't find one, but
			// in theory this action should only be called after one is created.
			// Normally, during checkout, the profile is created in
			// com.softslate.commerce.customer.payment.authorizeNetCIM.AuthorizeNetCIMForm#preparePaymentFormHook()
			// which means, do not try to add payment profiles until after the
			// payment form is shown to the user.

			// Verify we have a cc number because the baseForm will not check
			// anything if it is blank because it is also used for editing
			// payment profiles. Long story.
			if (StringUtils.isBlank(baseForm.getDecryptedNumber())) {
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("errors.cardNumberRequired"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				return mapping.findForward("failure");
			}

			// Send the request to Authorize.net
			Customer customer = baseForm.getUser().getCustomer();
			AuthorizeNetAPIProcessor apiProcessor = (AuthorizeNetAPIProcessor) baseForm.getBusinessObjectFactory()
					.createObject("authorizeNetAPIProcessorImplementer");
			String newPaymentProfileID = null;
			Map parameters = PropertyUtils.describe(baseForm);
			parameters.put("customerProfileID", customer.getCimProfileID());
			try {
				Map createPaymentProfileResult = apiProcessor.createPaymentProfile(parameters);
				newPaymentProfileID = (String) createPaymentProfileResult.get("newPaymentProfileID");
				log.info("newPaymentProfileID: " + newPaymentProfileID);
			} catch (Exception ex) {
				log.error("Exception adding payment profile: ", ex);
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.cimManageProfilesUnableToCreateProfile"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				return mapping.findForward("failure");
			}

			// Make sure it was created
			if (StringUtils.isBlank(newPaymentProfileID)) {
				baseForm.getErrors().add(ActionMessages.GLOBAL_MESSAGE,
						new ActionMessage("errors.cimManageProfilesUnableToCreateProfile"));
				saveErrors(baseForm.getRequest(), (ActionMessages) baseForm.getErrors());
				return mapping.findForward("failure");
			}

			// Add a message to tell the user it worked
			baseForm.getMessages().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("messages.cimProfileAdded"));
			saveMessages(baseForm.getRequest(), baseForm.getMessages());
			baseForm.getRequest().setAttribute("addressForm", baseForm);
			return mapping.findForward("success");
		}
	}
}
