package com.softslate.commerce.customer.payment;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;
import org.apache.struts.action.ActionMessages;

import com.softslate.commerce.customer.core.BaseForm;

/**
 * Struts form class for users electing to send the store payment by purchase
 * order. This form corresponds to the
 * {@link com.softslate.commerce.businessobjects.payment.PurchaseOrderPaymentProcessor}
 * payment processor.
 * <p>
 * Stores can use this form and the corresponding processor to offer payment by
 * purchase order as an option for their customers. Payment will be marked
 * "Pending". Once the payment is received, the store administrator can look up
 * and process the order.
 * <p>
 * The database settings "activePaymentProcessors", "activePaymentForms", and
 * "activePaymentFormTemplate" represent the various payment methods available
 * to users. During checkout, each of the "activePaymentForms" will be
 * instantiated and prepared for display on the checkout payment screen. When
 * the user submits payment information the <code>validate</code> method of the
 * corresponding payment form is invoked.
 * <p>
 * The <code>validate</code> method of this class simply returns a success
 * result.
 * 
 * @author Jason McWilliams
 */
public class PurchaseOrderPaymentForm extends BaseForm {

	/**
	 * 
	 */
	private static final long serialVersionUID = -2645291672424219965L;

	static Log log = LogFactory.getLog(PurchaseOrderPaymentForm.class);

	private String purchaseOrderNumber = null;

	public String getPurchaseOrderNumber() {
		return purchaseOrderNumber;
	}

	public void setPurchaseOrderNumber(String purchaseOrderNumber) {
		this.purchaseOrderNumber = purchaseOrderNumber;
	}

	private String purchaseOrderNotes = null;

	public String getPurchaseOrderNotes() {
		return purchaseOrderNotes;
	}

	public void setPurchaseOrderNotes(String purchaseOrderNotes) {
		this.purchaseOrderNotes = purchaseOrderNotes;
	}

	public ActionErrors validate(ActionMapping mapping, HttpServletRequest request) {
		if (log.isInfoEnabled())
			log.info("Starting validation.");
		initializeProperties(mapping, request);

		boolean canUsePO = getUser() != null && getUser().getCustomer() != null
				&& getUser().getCustomer().getCanUsePO();

		if (!canUsePO) {
			String purchaseOrderPermissionError = getMessage("order", "paymentForms.purchaseOrderPermissionError", null);
			getErrors().add(ActionMessages.GLOBAL_MESSAGE,
					new ActionMessage("errors.detail", purchaseOrderPermissionError));
			return getErrors();
		}

		String purchaseOrderNumber = getMessage("order", "paymentForms.purchaseOrderNumber", null);
		if (StringUtils.isBlank(getPurchaseOrderNumber())) {
			getErrors().add(ActionMessages.GLOBAL_MESSAGE, new ActionMessage("errors.required", purchaseOrderNumber));
		}

		if (log.isDebugEnabled())
			log.debug("Finished validation.");
		if (log.isInfoEnabled() && !getErrors().isEmpty())
			log.info("Validation error(s): " + getErrors().toString());
		return getErrors();
	}

}