package com.softslate.commerce.daos.customer;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;

import com.softslate.commerce.businessobjects.customer.CustomerAddress;
import com.softslate.commerce.daos.core.BaseDAO;
import com.softslate.commerce.daos.core.DataAccessException;

/**
 * Generic DAO to manage the <code>sscCustomerAddress</code> table of the
 * database.
 * 
 * @author David Tobey
 */
public class CustomerAddressDAOHibernate extends BaseDAO implements
        CustomerAddressDAO {

    static Log log = LogFactory.getLog(CustomerAddressDAOHibernate.class);

    private CustomerAddress customerAddress = null;

    public CustomerAddress getCustomerAddress() {
        return (this.customerAddress);
    }

    public void setCustomerAddress(CustomerAddress customerAddress) {
        this.customerAddress = customerAddress;
    }

    public void loadCustomerAddressFromID() throws Exception {
        Session session = getDaoFactory().startSession();
        try {
            CustomerAddress record = (CustomerAddress) session.get(
                    CustomerAddress.class, new Integer(getCustomerAddress()
                            .getCustomerAddressID()));
            PropertyUtils.copyProperties(getCustomerAddress(), record);
            setCustomerAddress(record);
        } catch (HibernateException he) {
            if (log.isErrorEnabled())
                log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

    public void insertCustomerAddress() throws DataAccessException {
        insertCustomerAddress(false);
    }

	public void insertCustomerAddress(boolean commit)
			throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			session.save(getCustomerAddress());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
			if (getCustomerAddress().getIsDefault()) {
				handleNewDefaultCustomerAddress();
			}
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

    public void updateCustomerAddress() throws DataAccessException {
        updateCustomerAddress(false);
    }

	public void updateCustomerAddress(boolean commit)
			throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			session.update(getCustomerAddress());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
			if (getCustomerAddress().getIsDefault()) {
				handleNewDefaultCustomerAddress();
			}
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

    public void deleteCustomerAddress() throws Exception {
        deleteCustomerAddress(false);
    }

    public void deleteCustomerAddress(boolean commit) throws Exception {
        Session session = getDaoFactory().startSession();
        try {
            setCustomerAddress((CustomerAddress) session.load(
                    CustomerAddress.class, new Integer(getCustomerAddress()
                            .getCustomerAddressID())));
            session.delete(getCustomerAddress());
            if (commit) {
                getDaoFactory().commitTransaction();
            }
        } catch (HibernateException he) {
            if (log.isErrorEnabled())
                log.error("Hibernate error: " + he.toString());
            throw new DataAccessException(he);
        }
        return;
    }

	public void handleNewDefaultCustomerAddress() throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			Query q = getNamedQuery(session,
					"customer.handleNewDefaultCustomerAddress");
			q.setInteger("customerID", getCustomerAddress().getCustomerID());
			q.setInteger("customerAddressID", getCustomerAddress()
					.getCustomerAddressID());
			q.executeUpdate();
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
		}
		return;

	}

}
