package com.softslate.commerce.daos.product;

import java.util.Map;

import org.apache.commons.beanutils.PropertyUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;

import com.softslate.commerce.businessobjects.core.BusinessObjectFactory;
import com.softslate.commerce.businessobjects.product.SKU;
import com.softslate.commerce.daos.core.BaseDAO;
import com.softslate.commerce.daos.core.DAOInterface;
import com.softslate.commerce.daos.core.DataAccessException;

/**
 * Generic DAO to manage the <code>sscSKU</code> table of the database.
 * 
 * @author David Tobey
 */
public class SKUDAOHibernate extends BaseDAO implements DAOInterface, SKUDAO {

	static Log log = LogFactory.getLog(SKUDAOHibernate.class);

	private SKU sku = null;

	public SKU getSKU() {
		return (this.sku);
	}

	public void setSKU(SKU sku) {
		this.sku = sku;
	}

	public void loadSKUFromID() throws Exception {
		Session session = getDaoFactory().startSession();
		try {
			SKU sku = (SKU) session.get(SKU.class, new Integer(getSKU()
					.getSKUID()));
			if (sku != null) {
				PropertyUtils.copyProperties(getSKU(), sku);
			}
			setSKU(sku);
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public void loadSKUFromSKUNumber() throws Exception {
		Session session = getDaoFactory().startSession();
		try {
			Query q = getNamedQuery(session, "sku.selectSKUFromSKUNumber");
			q.setString("skuNumber", getSKU().getSkuNumber());
			SKU loadedSKU = (SKU) q.uniqueResult();
			setSKU(loadedSKU);
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public void loadProductSKU() throws Exception {
		Session session = getDaoFactory().startSession();
		try {
			Query q = getNamedQuery(session, "sku.selectProductSKU");
			q.setInteger("productID", getSKU().getProductID().intValue());
			SKU loadedSKU = (SKU) q.uniqueResult();
			setSKU(loadedSKU);
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public Object loadObject(Object object) throws Exception {
		if (null != object && object instanceof SKU) {
			this.setSKU((SKU) object);
			if (0 != this.getSKU().getSkuID()) {
				this.loadSKUFromID();
			} else if (null != this.getSKU().getSkuNumber()) {
				this.loadSKUFromSKUNumber();
			}
			return this.getSKU();
		}
		return null;
	}

	public void insertSKU() throws DataAccessException {
		insertSKU(false);
	}

	public void insertSKU(boolean commit) throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			session.save(getSKU());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
			evictCache();
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public Object insertObject(Object object, boolean commit) throws Exception {
		if (null != object && object instanceof SKU) {
			this.setSKU((SKU) object);
			this.insertSKU(commit);
			return this.getSKU();
		}
		return null;
	}

	public void updateSKU() throws DataAccessException {
		updateSKU(false);
	}

	public void updateSKU(boolean commit) throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			session.update(getSKU());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public Object updateObject(Object object, boolean commit) throws Exception {
		if (null != object && object instanceof SKU) {
			this.setSKU((SKU) object);
			this.updateSKU(commit);
			return this.getSKU();
		}
		return null;

	}

	public void deleteSKU() throws DataAccessException {
		deleteSKU(false);
	}

	public void deleteSKU(boolean commit) throws DataAccessException {
		Session session = getDaoFactory().startSession();
		try {
			setSKU((SKU) session.load(SKU.class, new Integer(getSKU()
					.getSKUID())));
			session.delete(getSKU());
			if (commit) {
				getDaoFactory().commitTransaction();
			}
			evictCache();
		} catch (HibernateException he) {
			if (log.isErrorEnabled())
				log.error("Hibernate error: " + he.toString());
			throw new DataAccessException(he);
		}
		return;
	}

	public Map editSKUAssignment(SKU sku, Map parameters, BusinessObjectFactory bof) throws Exception {
		Map result = editAssignment(sku, parameters, bof);
		evictCache();
		return result;
	}

}
