CREATE TABLE sscShippingMethod (
  shippingMethodID INT(11) NOT NULL AUTO_INCREMENT,
  code VARCHAR(100) NOT NULL DEFAULT '',
  name VARCHAR(255) DEFAULT NULL,
  minimum DECIMAL(10,4) NOT NULL DEFAULT '0',
  base DECIMAL(10,4) NOT NULL DEFAULT '0',
  methodType VARCHAR(100) NOT NULL,
  isActive TINYINT(4) NOT NULL DEFAULT '0',
  numberDaysToShip INT(11) DEFAULT NULL,
  methodOrder INT(11) DEFAULT NULL,
  class VARCHAR(255) DEFAULT 'com.softslate.commerce.businessobjects.shipping.ShippingMethodBean',
  PRIMARY KEY  (shippingMethodID),
  UNIQUE KEY shippingMethodCode (code),
  KEY shippingMethodCodeIndex (code)
);

ALTER TABLE sscShippingMethod ADD 
  (isPickUp tinyint(4) NOT NULL DEFAULT '0',
  organization VARCHAR(100) DEFAULT NULL,
  address1 VARCHAR(255) DEFAULT NULL,
  address2 VARCHAR(255) DEFAULT NULL,
  city VARCHAR(100) DEFAULT NULL,
  state VARCHAR(100) DEFAULT NULL,
  postalCode VARCHAR(100) DEFAULT NULL,
  country VARCHAR(100) DEFAULT NULL);

CREATE INDEX IDX_sscShippingMethod_name ON sscShippingMethod (name);
CREATE INDEX IDX_sscSM_methodOrder ON sscShippingMethod (methodOrder);

CREATE TABLE sscShippingRate (
  shippingRateID INT(11) NOT NULL AUTO_INCREMENT,
  shippingMethodID INT(11) NOT NULL,
  floor DECIMAL(10,4) NOT NULL DEFAULT '0',
  ceiling DECIMAL(10,4) NOT NULL DEFAULT '0',
  amount DECIMAL(10,4) NOT NULL DEFAULT '0',
  isActive TINYINT(4) NOT NULL DEFAULT '0',
  class VARCHAR(255) DEFAULT 'com.softslate.commerce.businessobjects.shipping.ShippingRateBean',
  PRIMARY KEY  (shippingRateID),
  KEY shippingMethodIDIndex (shippingMethodID),
  FOREIGN KEY (`shippingMethodID`) REFERENCES `sscShippingMethod` (`shippingMethodID`) ON DELETE CASCADE
);

CREATE INDEX IDX_sscShippingRate_amount ON sscShippingRate (amount);

CREATE TABLE sscShippingRule (
  shippingRuleID INT(11) NOT NULL AUTO_INCREMENT,
  code VARCHAR(100) NOT NULL DEFAULT '',
  name VARCHAR(255) DEFAULT NULL,
  description TEXT,
  isActive TINYINT(4) NOT NULL DEFAULT '1',
  ruleType VARCHAR(32) DEFAULT NULL,
  ruleOrder INT(11) NOT NULL DEFAULT '0',
  extra1 VARCHAR(255) DEFAULT NULL,
  extra2 VARCHAR(255) DEFAULT NULL,
  extra3 VARCHAR(255) DEFAULT NULL,
  class VARCHAR(255) DEFAULT 'com.softslate.commerce.businessobjects.shipping.ShippingRuleBean',
  PRIMARY KEY  (shippingRuleID),
  UNIQUE KEY shippingRuleCodeUKey (code)
);

CREATE INDEX IDX_sscShippingRule_name ON sscShippingRule (name);
CREATE INDEX IDX_sscShippingRule_ruleOrder ON sscShippingRule (ruleOrder);

CREATE TABLE sscSKUShippingRule (
  skuShippingRuleID INT(11) NOT NULL AUTO_INCREMENT,
  skuID INT(11) NOT NULL DEFAULT '0',
  shippingRuleID INT(11) NOT NULL DEFAULT '0',
  class VARCHAR(255) DEFAULT 'com.softslate.commerce.businessobjects.shipping.SKUShippingRuleBean',
  PRIMARY KEY  (skuShippingRuleID),
  KEY skuIDIndex (skuID),
  FOREIGN KEY (`skuID`) REFERENCES `sscSKU` (`skuID`) ON DELETE CASCADE,
  KEY shippingRuleIDIndex (shippingRuleID),
  UNIQUE KEY shippingRuleCodeUKey (skuID, shippingRuleID),
  FOREIGN KEY (`shippingRuleID`) REFERENCES `sscShippingRule` (`shippingRuleID`) ON DELETE CASCADE
);

CREATE TABLE sscShippingRuleRange (
  shippingRuleRangeID INT(11) NOT NULL AUTO_INCREMENT,
  shippingRuleID INT(11) NOT NULL,
  floor DECIMAL(10,4) NOT NULL DEFAULT '0',
  ceiling DECIMAL(10,4) NOT NULL DEFAULT '0',
  isActive TINYINT(4) NOT NULL DEFAULT '1',
  discountType VARCHAR(32) DEFAULT NULL,
  discount DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgDescription TEXT,
  pkgWeight DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgLength DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgHeight DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgWidth DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgExtra1 VARCHAR(255) DEFAULT NULL,
  pkgExtra2 VARCHAR(255) DEFAULT NULL,
  pkgExtra3 VARCHAR(255) DEFAULT NULL,
  pkgExtra4 VARCHAR(255) DEFAULT NULL,
  pkgExtra5 VARCHAR(255) DEFAULT NULL,
  countries TEXT,
  states TEXT,
  limitMethods TEXT,
  limitType VARCHAR(32) DEFAULT NULL,
  class VARCHAR(255) DEFAULT 'com.softslate.commerce.businessobjects.shipping.ShippingRuleRangeBean',
  PRIMARY KEY  (shippingRuleRangeID),
  KEY shippingRuleIDIndex (shippingRuleID),
  FOREIGN KEY (`shippingRuleID`) REFERENCES `sscShippingRule` (`shippingRuleID`) ON DELETE CASCADE
);

CREATE TABLE sscOrderShippingRule (  
  orderShippingRuleID INT(11) NOT NULL AUTO_INCREMENT,
  orderID INT(11) NOT NULL DEFAULT '0',
  orderItemID INT(11) NULL,
  total DECIMAL(10,4) DEFAULT NULL,
  shippingRuleID INT(11) NOT NULL DEFAULT '0',
  code VARCHAR(100) NOT NULL DEFAULT '',
  name VARCHAR(255) DEFAULT NULL,
  ruleType VARCHAR(32) DEFAULT NULL,
  floor DECIMAL(10,4) DEFAULT NULL,
  ceiling DECIMAL(10,4) DEFAULT NULL,
  discountType VARCHAR(32) DEFAULT NULL,
  discount DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgDescription TEXT,
  pkgWeight DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgLength DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgHeight DECIMAL(10,4) NOT NULL DEFAULT '0',
  pkgWidth DECIMAL(10,4) NOT NULL DEFAULT '0',
  limitMethods TEXT,
  limitType VARCHAR(32) DEFAULT NULL,
  extra1 VARCHAR(255) DEFAULT NULL,
  extra2 VARCHAR(255) DEFAULT NULL,
  extra3 VARCHAR(255) DEFAULT NULL,
  pkgExtra1 VARCHAR(255) DEFAULT NULL,
  pkgExtra2 VARCHAR(255) DEFAULT NULL,
  pkgExtra3 VARCHAR(255) DEFAULT NULL,
  pkgExtra4 VARCHAR(255) DEFAULT NULL,
  pkgExtra5 VARCHAR(255) DEFAULT NULL,
  countries TEXT,
  states TEXT,
  subtotal DECIMAL(10,4) DEFAULT NULL,
  class VARCHAR(255) DEFAULT 'com.softslate.commerce.businessobjects.order.OrderShippingRuleBean',
  PRIMARY KEY  (orderShippingRuleID),
  KEY orderIDIndex (orderID),
  FOREIGN KEY (`orderID`) REFERENCES `sscOrder` (`orderID`) ON DELETE CASCADE
);

CREATE INDEX IDX_sscOrderShippingRule_orderItemID ON sscOrderShippingRule (orderItemID);
CREATE INDEX IDX_sscOrderShippingRule_total ON sscOrderShippingRule (total);
CREATE INDEX IDX_sscOrderShippingRule_code ON sscOrderShippingRule (code);
CREATE INDEX IDX_sscOrderShippingRule_name ON sscOrderShippingRule (name);


